@@ -20,8 +20,8 @@ for my $my_graph (GD::Graph::bars->new, GD::Graph::hbars->new)
 	x_label         => 'X Label',
 	y_label         => 'Y label',
 	title           => 'Bars in front of each other',
-	y_tick_number   => 8,
-	y_label_skip    => 2,
+	#y_tick_number   => 8,
+	#y_label_skip    => 2,
 	overwrite       => 1,
 	bar_spacing     => 8,
 	shadow_depth    => 4,
