@@ -1,7 +1,7 @@
 use GD::Graph::lines;
 require 'save.pl';
 
-print STDERR "Processing sample 5-1\n";
+print STDERR "Processing sample51\n";
 
 # The reverse is in here, because I thought the falling line was 
 # depressing, but I was too lazy to retype the data set
@@ -23,6 +23,8 @@ $my_graph->set(
 	y_label_skip => 2,
 	box_axis => 0,
 	line_width => 3,
+
+	transparent => 0,
 );
 
 $my_graph->plot(\@data);
